==> skill-admin-service-0.0.2.jar: dbscript/all.sql <==
-- ----------------------------
-- Table structure for `user`
-- ----------------------------
-- DROP TABLE IF EXISTS `user`;
CREATE TABLE `user` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `mobile` varchar(100) NOT NULL  ,  
    `password` Varchar(50) NOT NULL  ,  
    `name` Varchar(200)   ,  
    `sex` Varchar(50)   ,  
    `email` Varchar(100)   ,  
    `province` Varchar(100)   ,  
    `city` Varchar(100)   ,  
    `county` Varchar(100)   ,  
    `mail` Varchar(100)   ,  
    `address` Varchar(100)   ,  
    `login_at` bigint   ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;




-- ----------------------------
-- Table structure for `indent`
-- ----------------------------
-- DROP TABLE IF EXISTS `indent`;
CREATE TABLE `indent` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `indentity` varchar(100) NOT NULL  ,  
    `product` Varchar(50) NOT NULL  ,  
    `address` Varchar(200)   ,  
    `uid` bigint NOT NULL  ,  
    `size` Varchar(100) NOT NULL  ,  
    `texture` Varchar(100)   ,  
    `num` Varchar(100) NOT NULL  ,  
    `img` Varchar(100)   ,  
    `fprice` Varchar(100) NOT NULL  ,  
    `bprice` Varchar(100) NOT NULL  ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;




-- ----------------------------
-- Table structure for `address`
-- ----------------------------
-- DROP TABLE IF EXISTS `address`;
CREATE TABLE `address` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `uid` bigint NOT NULL  ,  
    `province` Varchar(50)   ,  
    `city` Varchar(50)   ,  
    `county` Varchar(50)   ,  
    `shop` Varchar(100)   ,  
    `receiver` Varchar(100)   ,  
    `address` Varchar(200)   ,  
    `mobile` Varchar(100)   ,  
    `first` bigint NOT NULL  ,  
    `last_time` bigint   ,  
    `email` Varchar(100)   ,  
    `mail` Varchar(100)   ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;

==> skill-admin-service-1.1.1.jar: dbscript/all.sql <==
-- ----------------------------
-- Table structure for `user`
-- ----------------------------
-- DROP TABLE IF EXISTS `user`;
CREATE TABLE `user` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `mobile` varchar(100) NOT NULL  ,  
    `password` Varchar(50) NOT NULL  ,  
    `name` Varchar(200)   ,  
    `sex` Varchar(50)   ,  
    `email` Varchar(100)   ,  
    `province` Varchar(100)   ,  
    `city` Varchar(100)   ,  
    `county` Varchar(100)   ,  
    `mail` Varchar(100)   ,  
    `address` Varchar(100)   ,  
    `login_at` bigint   ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;




-- ----------------------------
-- Table structure for `indent`
-- ----------------------------
-- DROP TABLE IF EXISTS `indent`;
CREATE TABLE `indent` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `indentity` varchar(100) NOT NULL  ,  
    `product` Varchar(50) NOT NULL  ,  
    `address` Varchar(200)   ,  
    `uid` bigint NOT NULL  ,  
    `size` Varchar(100) NOT NULL  ,  
    `texture` Varchar(100)   ,  
    `num` Varchar(100) NOT NULL  ,  
    `img` Varchar(100)   ,  
    `fprice` Varchar(100) NOT NULL  ,  
    `bprice` Varchar(100) NOT NULL  ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;




-- ----------------------------
-- Table structure for `address`
-- ----------------------------
-- DROP TABLE IF EXISTS `address`;
CREATE TABLE `address` (
    `id` bigint NOT NULL   AUTO_INCREMENT ,  
    `uid` bigint NOT NULL  ,  
    `province` Varchar(50)   ,  
    `city` Varchar(50)   ,  
    `county` Varchar(50)   ,  
    `shop` Varchar(100)   ,  
    `receiver` Varchar(100)   ,  
    `address` Varchar(200)   ,  
    `mobile` Varchar(100)   ,  
    `first` bigint NOT NULL  ,  
    `last_time` bigint   ,  
    `email` Varchar(100)   ,  
    `mail` Varchar(100)   ,  
    `create_by` bigint   ,  
    `update_by` bigint   ,  
    `update_at` bigint NOT NULL  ,  
    `create_at` bigint NOT NULL  ,  
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;



-- ----------------------------
-- Table structure for `contents`
-- ----------------------------
-- DROP TABLE IF EXISTS `contents`;
CREATE TABLE `contents` (
    `id` bigint NOT NULL   AUTO_INCREMENT  COMMENT 'id',
    `type` int(3) NOT NULL   COMMENT '类型',
    `img` varchar(255)    COMMENT '图片链接',
    `title` text(500)    COMMENT '标题',
    `level` int(3)    COMMENT '排序',
    `author` varchar(50)    COMMENT '作者',
    `content` mediumtext(150000)    COMMENT '内容',
    `summary` varchar(200)    COMMENT '摘要',
    `url` varchar(255)    COMMENT '链接(文章来源)',
    `status` int(1) NOT NULL   COMMENT '是否发布',
    `create_by` bigint    COMMENT '创建人ID',
    `update_by` bigint    COMMENT '更新人ID',
    `publish_at` bigint NOT NULL   COMMENT '发布时间',
    `update_at` bigint NOT NULL   COMMENT '数据更新时间',
    `create_at` bigint NOT NULL   COMMENT '数据创建时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;
